Coverage for src/configuraptor/__init__.py: 100%

1"""

2 Exposes TypedConfig and load_into for this library.

3"""

4

5# SPDX-FileCopyrightText: 2023-present Robin van der Noord <robinvandernoord@gmail.com>

6#

7# SPDX-License-Identifier: MIT

8 from .cls import TypedConfig # noqa: F401 imported for library reasons

9 from .core import ( # noqa: F401 imported for library reasons

10 all_annotations,

11 check_type,

12 ensure_types,

13 load_into,

14)

15 from .singleton import ( # noqa: F401 imported for library reasons

16 Singleton,

17 SingletonMeta,

18)